Name:          swizzle
Version:       1.6.2
Release:       10%{?dist}
Summary:       Collection of Java data processing and RPC utilities
License:       ASL 2.0
URL:           https://github.com/codehaus/swizzle
Source0:       https://github.com/codehaus/swizzle/archive/%{name}-%{version}.tar.gz
# swizzle package don't include the license file
# reported @ http://jira.codehaus.org/browse/SWIZZLE-61
#            https://github.com/codehaus/swizzle/issues/1
Source1:       http://www.apache.org/licenses/LICENSE-2.0.txt

BuildRequires: maven-local
BuildRequires: mvn(commons-collections:commons-collections)
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(log4j:log4j:1.2.17)
BuildRequires: mvn(org.apache.velocity:velocity)
BuildRequires: mvn(org.apache.xmlrpc:xmlrpc-client)
BuildRequires: mvn(org.slf4j:slf4j-api)
BuildRequires: mvn(org.sonatype.oss:oss-parent:pom:)

BuildArch:     noarch

%description
Collection of Java data processing and RPC utilities.

%package confluence
Summary:       Swizzle :: Confluence

%description confluence
Strongly typed Java Client for the Confluence XML-RPC API.
Can add, update, find and delete pages and more.

%package jira
Summary:       Swizzle :: JIRA

%description jira
Strongly typed Java Client for the Jira XML-RPC API or the
JIRA RSS API. Far more expressive and natural to code against.
Implements caching of response data. Can screen scrape using
Swizzle Stream for data which is not available through XML-RPC
or RSS, such as lists of voters or sub-tasks for a given item.

%package jirareport
Summary:       Swizzle :: JIRA Report

%description jirareport
A simple command line utility library that combines Velocity with
Swizzle JIRA to easily create reports. The Velocity template
is 100% self contained, no "coding" necessary. Simply point the
swizzle-jirareport jar at a velocity template and get your
formatted data back.

%package stream
Summary:       Swizzle :: Stream

%description stream
Stream editor implemented as a series of InputStream and
OutputStream filters. Like the UNIX SED and can manipulate an
endless stream with little memory. Unlike SED it does not support
regular expressions, but the lack of it keeps buffering down and
processing fast as all scanning is done with string literals of
known content and length.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}

cp -p %{SOURCE1} LICENSE
sed -i 's/\r//' LICENSE

%pom_remove_plugin :maven-assembly-plugin %{name}-jirareport

for m in confluence jira; do
%pom_change_dep org.sonatype.sisu:sisu-xmlrpc-client org.apache.xmlrpc:xmlrpc-client:3.1.3 %{name}-${m}
done

# Change  org.sonatype.sisu:sisu-xmlrpc-client support (project seem upstream dead) with Apache xmlrpc-client
sed -i "s|XmlRpcAhcTransportFactory|XmlRpcCommonsTransportFactory|" \
 %{name}-confluence/src/main/java/org/codehaus/swizzle/confluence/Confluence.java \
 %{name}-jira/src/main/java/org/codehaus/swizzle/jira/Jira.java

%pom_change_dep :log4j :log4j:1.2.17 %{name}-jirareport
%pom_change_dep :velocity org.apache.velocity: %{name}-jirareport

# Disable tests, required web connection
# org.codehaus.swizzle.confluence.ConfluenceException:
# I/O error while communicating with HTTP server: docs.codehaus.org
rm -r %{name}-confluence/src/test \
 %{name}-jira/src/test \
 %{name}-jirareport/src/test

%build

%mvn_build -s -- -Dproject.build.sourceEncoding=UTF-8

%install
%mvn_install

%files -f .mfiles-%{name}
%license LICENSE

%files confluence -f .mfiles-%{name}-confluence
%license LICENSE

%files jira -f .mfiles-%{name}-jira
%license LICENSE

%files jirareport -f .mfiles-%{name}-jirareport
%license LICENSE

%files stream -f .mfiles-%{name}-stream
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Sun Feb 03 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.2-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.2-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Nov 04 2015 gil cattaneo <puntogil@libero.it> 1.6.2-4
- fix URL and Source0 field
- remove duplicate file

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Mar 09 2015 gil cattaneo <puntogil@libero.it> 1.6.2-2
- fix summary and description
- disable confluence/jira/jirareport tests

* Wed Jun 12 2013 gil cattaneo <puntogil@libero.it> 1.6.2-1
- initial rpm
